<?php
/**
 * Woocommerce Compare page
 *
 * @author Your Inspiration Themes
 * @package YITH Woocommerce Compare
 * @version 1.1.4
 */

// remove the style of woocommerce
if( defined('WOOCOMMERCE_USE_CSS') && WOOCOMMERCE_USE_CSS ) wp_dequeue_style('woocommerce_frontend_styles');

$is_iframe = (bool)( isset( $_REQUEST['iframe'] ) && $_REQUEST['iframe'] );

wp_enqueue_script( 'jquery-fixedheadertable', YITH_WOOCOMPARE_ASSETS_URL . '/js/jquery.dataTables.min.js', array('jquery'), '1.3', true );
wp_enqueue_script( 'jquery-fixedcolumns', YITH_WOOCOMPARE_ASSETS_URL . '/js/FixedColumns.min.js', array('jquery', 'jquery-fixedheadertable'), '1.3', true );

$widths = array();
foreach( $products as $product ) $widths[] = '{ "sWidth": "205px", resizeable:true }';

/** FIX WOO 2.1 */
$wc_get_template = function_exists('wc_get_template') ? 'wc_get_template' : 'woocommerce_get_template';

$table_text = get_option( 'yith_woocompare_table_text' );
$localized_table_text = function_exists( 'icl_translate' ) ? icl_translate( 'Plugins', 'plugin_yit_compare_table_text', $table_text ) : $table_text;

?><!DOCTYPE html>
<!--[if IE 6]>
<html id="ie6" class="ie"<?php language_attributes() ?>>
<![endif]-->
<!--[if IE 7]>
<html id="ie7" class="ie"<?php language_attributes() ?>>
<![endif]-->
<!--[if IE 8]>
<html id="ie8" class="ie"<?php language_attributes() ?>>
<![endif]-->
<!--[if IE 9]>
<html id="ie9" class="ie"<?php language_attributes() ?>>
<![endif]-->
<!--[if gt IE 9]>
<html class="ie"<?php language_attributes() ?>>
<![endif]-->
<!--[if !IE]>
<html <?php language_attributes() ?>>
<![endif]-->

<!-- START HEAD -->
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>" />
	<meta name="viewport" content="width=device-width" />
	<link rel="profile" href="https://gmpg.org/xfn/11" />

	<link href='https://fonts.googleapis.com/css?family=Roboto&subset=latin,latin-ext' rel='stylesheet' type='text/css'>
	<link rel="stylesheet" href="<?php echo esc_url($this->stylesheet_url()) ?>" type="text/css" />
	<link rel="stylesheet" href="<?php echo esc_url(SHOPME_BASE_URI . 'css/fontello.css') ?>" />
	<link rel="stylesheet" href="<?php echo esc_url(SHOPME_COMPARE_URI . '/colorbox.css') ?>"/>
	<link rel="stylesheet" href="<?php echo esc_url(SHOPME_COMPARE_URI . '/jquery.dataTables.css') ?>"/>

	<?php
	global $shopme_theme_data;
	$prefix_name = sanitize_file_name($shopme_theme_data['name']);

	if ( get_option('exists_stylesheet'. $prefix_name ) == true ) {
		$upload_dir = wp_upload_dir();
		if ( is_ssl() ) {
			$upload_dir['baseurl'] = str_replace("http://", "https://", $upload_dir['baseurl']);
		}
		?>
		<link rel="stylesheet" href="<?php echo $upload_dir['baseurl'] . '/dynamic_shopme_dir/' . $prefix_name . '.css' ?>">
	<?php } ?>

	<?php if (is_rtl()): ?>
		<link rel="stylesheet" href="<?php echo esc_url(SHOPME_COMPARE_URI . '/rtl.css') ?>" type="text/css" />
	<?php endif; ?>

	<?php wp_head() ?>

	<style type="text/css">
		body.loading {
			background: url("<?php echo SHOPME_BASE_URI ?>images/ajax-loader@2x.gif") no-repeat scroll center center transparent;
		}
	</style>
</head>
<!-- END HEAD -->

<?php global $product; ?>

<!-- START BODY -->
<body <?php body_class('woocommerce') ?>>

<h2>
	<?php echo $localized_table_text ?>
	<?php if ( ! $is_iframe ) : ?><a class="close" href="#"><?php esc_html_e( 'Close window [X]', 'shopme' ) ?></a><?php endif; ?>
</h2>

<?php do_action( 'yith_woocompare_before_main_table' ); ?>

<table class="compare-list" cellpadding="0" cellspacing="0"<?php if ( empty( $products ) ) echo ' style="width:100%"' ?>>
	<thead>
	<tr>
		<th>&nbsp;</th>
		<?php foreach( $products as $i => $product ) : ?>
			<td></td>
		<?php endforeach; ?>
	</tr>
	</thead>
	<tfoot>
	<tr>
		<th>&nbsp;</th>
		<?php foreach( $products as $i => $product ) : ?>
			<td></td>
		<?php endforeach; ?>
	</tr>
	</tfoot>
	<tbody>

	<?php if ( empty( $products ) ) : ?>

		<tr class="no-products">
			<td><?php esc_html_e( 'No products added in the compare table.', 'shopme' ) ?></td>
		</tr>

	<?php else : ?>

		<?php foreach ( $fields as $field => $name ) : ?>

			<tr class="<?php echo $field ?>">

				<th>
					<?php echo $name ?>
					<?php if ( $field == 'image' ) echo '<div class="fixed-th"></div>'; ?>
				</th>

				<?php foreach( $products as $product_id => $product ) :
					?>
					<td><?php
						switch( $field ) {

							case 'image':
								echo '<div class="image-wrap">' . wp_get_attachment_image( $product->fields[$field], 'yith-woocompare-image' ) . '</div>';
								break;

							case 'add-to-cart':
								woocommerce_template_loop_add_to_cart();
								echo '<div class="remove">';
									echo '<a href="' . esc_url(add_query_arg( 'redirect', 'view', $this->remove_product_url( $product_id ) )) . '" data-product_id="' . $product_id.'"></a>';
								echo '</div>';
								break;
							default:
								echo empty( $product->fields[$field] ) ? '&nbsp;' : $product->fields[$field];
								break;
						}
						?>
					</td>
				<?php endforeach ?>

			</tr>

		<?php endforeach; ?>

		<?php if ( $repeat_price == 'yes' && isset( $fields['price'] ) ) : ?>
			<tr class="price repeated">
				<th><?php echo $fields['price'] ?></th>

				<?php
				$index = 0;
				foreach( $products as $product_id => $product ) :
					$product_class = ( $index % 2 == 0 ? 'odd' : 'even' ) . ' product_' . $product_id ?>
					<td class="<?php echo $product_class ?>"><?php echo $product->fields['price'] ?></td>
					<?php
					++$index;
				endforeach; ?>

			</tr>
		<?php endif; ?>

		<?php if ( $repeat_add_to_cart == 'yes' && isset( $fields['add-to-cart'] ) ) : ?>
			<tr class="add-to-cart repeated">
				<th><?php echo $fields['add-to-cart'] ?></th>

				<?php
				$index = 0;
				foreach( $products as $product_id => $product ) :
					$product_class = ( $index % 2 == 0 ? 'odd' : 'even' ) . ' product_' . $product_id ?>
					<td class="<?php echo $product_class ?>">
						<?php woocommerce_template_loop_add_to_cart(); ?>
					</td>
					<?php
					++$index;
				endforeach; ?>

			</tr>
		<?php endif; ?>

	<?php endif; ?>

	</tbody>
</table>

<?php do_action( 'yith_woocompare_after_main_table' ); ?>

<?php if( wp_script_is( 'responsive-theme', 'enqueued' ) ) wp_dequeue_script( 'responsive-theme' ) ?><?php if( wp_script_is( 'responsive-theme', 'enqueued' ) ) wp_dequeue_script( 'responsive-theme' ) ?>
<?php do_action('wp_print_footer_scripts'); ?>

<script type="text/javascript">

	jQuery(document).ready(function($){
		<?php if ( $is_iframe ) : ?>$('a').attr('target', '_parent');<?php endif; ?>

		var oTable;
		$('body').on( 'yith_woocompare_render_table', function(){
			if( $( window ).width() > 767 ) {
				oTable = $('table.compare-list').dataTable( {
					"sScrollX": "100%",
					//"sScrollXInner": "150%",
					"bScrollInfinite": true,
					"bScrollCollapse": true,
					"bPaginate": false,
					"bSort": false,
					"bInfo": false,
					"bFilter": false,
					"bAutoWidth": false
				} );

				new FixedColumns( oTable );
				$('<table class="compare-list" />').insertAfter( $('h2') ).hide();
			}
		}).trigger('yith_woocompare_render_table');

		// add to cart
		var button_clicked;
		$(document).on('click', 'a.add_to_cart_button', function(){
			button_clicked = $(this);
			button_clicked.block({message: null, overlayCSS: {background: '#fff url(' + woocommerce_params.ajax_loader_url + ') no-repeat center', backgroundSize: '16px 16px', opacity: 0.6}});
		});

		// remove add to cart button after added
		$('body').on('added_to_cart', function(){
			button_clicked.hide();

			<?php if ( $is_iframe ) : ?>
			$('a').attr('target', '_parent');

			// Replace fragments
			if ( fragments ) {
				$.each(fragments, function(key, value) {
					$(key, window.parent.document).replaceWith(value);
				});
			}
			<?php endif; ?>
		});

		// close window
		$(document).on( 'click', 'a.close', function(e){
			e.preventDefault();
			window.close();
		});

		$(window).on( 'yith_woocompare_product_removed', function(){
			if( $( window ).width() > 767 ) {
				oTable.fnDestroy(true);
			}
			$('body').trigger('yith_woocompare_render_table');
		});

	});

</script>

</body>
</html>